@@ -33,11 +33,14 @@
 #'  Default:RColorBrewer::brewer.pal(9, 'Greys')[c(3,6,4,7,5)]
 #'@param verbose logical, print plot summary, Default: F
 #'@param stratum_labels logical, Default: TRUE
+#'@param stratum_label_size numeric, Default: 4.5
 #'@param stratum_width double, Default: 1/4
 #'@param auto_rotate_xlabs logical, Default: TRUE
+#'@param ... additional parameter passed to \code{\link[easyalluvial]{manip_bin_numerics}}
 #'@return ggplot2 object
 #'@seealso \code{\link[easyalluvial]{alluvial_wide}}
 #'  ,\code{\link[ggalluvial]{geom_flow}}, \code{\link[ggalluvial]{geom_stratum}}
+#'  ,\code{\link[easyalluvial]{manip_bin_numerics}}
 #' @examples
 #'
 #'
@@ -114,8 +117,10 @@ alluvial_long = function( data
                           , col_vector_value =  RColorBrewer::brewer.pal(9, 'Greys')[c(3,6,4,7,5)]
                           , verbose = F
                           , stratum_labels = T
+                          , stratum_label_size = 4.5
                           , stratum_width = 1/4
                           , auto_rotate_xlabs = T
+                          , ...
 ){
 
   # quosures
@@ -136,30 +141,65 @@ alluvial_long = function( data
   value = as.name( value_str )
   id = as.name( id_str )
 
-  # ungroup
-  
-  data = ungroup(data)
-  
   # fill
-
+  
   if( rlang::quo_is_null(fill) ){
     fill_str = NULL
   }else{
     fill_str = quo_name(fill)
     fill = as.name( fill_str )
   }
+  
+
+  # store params to attach to plot
+  
+  params = list(
+  key = key_str
+  , value = value_str
+  , id = id_str
+  , fill = fill_str
+  , fill_right = fill_right
+  , bins = bins
+  , bin_labels = bin_labels
+  , NA_label = NA_label
+  , order_levels_value = order_levels_value
+  , order_levels_key = order_levels_key
+  , order_levels_fill = order_levels_fill
+  , complete = complete
+  , fill_by = fill_by
+  , col_vector_flow = col_vector_flow
+  , col_vector_value =  col_vector_value
+  , verbose = verbose
+  , stratum_labels = stratum_labels
+  , stratum_width = stratum_width
+  , auto_rotate_xlabs = auto_rotate_xlabs
+  )
+  
+  # ungroup
+  
+  data = ungroup(data)
 
   # transform numerical variables for binning
 
-  data_trans = data %>%
+  data = data %>%
     ungroup() %>%
     select( one_of( c(key_str, value_str, id_str, fill_str) ) ) %>%
     mutate( !! key_str := as.factor( !! key )
             , !! id_str := as.factor( !! id )
-            ) %>%
-    manip_bin_numerics( bins, bin_labels) %>%
+            )
+  
+
+  data_trans = data %>%
+    manip_bin_numerics( bins, bin_labels, NA_label = NA_label, ... ) %>%
     mutate( !! value_str := as.factor( !! value ) )
 
+  if( ! is_null(fill_str) ){
+    if( fill_str %in% levels(data_trans[[key_str]]) ){
+      stop( paste( 'Name of fill variable/column:', fill_str, ', cannot be one of'
+                   , levels(data_trans[[key_str]]) ) )
+    }
+  }
+  
   #complete data
 
   if( is.null(fill_str) ){
@@ -173,12 +213,10 @@ alluvial_long = function( data
       group_by( !! id, !! fill) %>%
       summarise()
 
-    suppressMessages({
-      data_trans = data_trans %>%
-        complete( !! key , !! id ) %>% ## leaves NA values for fill
-        select( - !! fill ) %>%     ## deselect and rejoin fill
-        left_join( id_2_fill_keys )
-    })
+    data_trans = data_trans %>%
+      complete( !! key , !! id ) %>% ## leaves NA values for fill
+      select( - !! fill ) %>%     ## deselect and rejoin fill
+      left_join( id_2_fill_keys, by = id_str )
 
   }
 
@@ -189,7 +227,7 @@ alluvial_long = function( data
 
   if( ! is.null(fill_str) ){
     ordered_levels_fill = c( order_levels_fill, levels( select(data_trans, !! fill)[[1]] ) ) %>% unique()
-    ordered_levels_y = c( ordered_levels_y, ordered_levels_fill)
+    ordered_levels_y = c( ordered_levels_y, ordered_levels_fill) %>% unique()
 
     if(fill_right){
       ordered_levels_x = c( ordered_levels_x, fill_str )
@@ -217,13 +255,14 @@ alluvial_long = function( data
     
     # to ensure dbplyr 0.8.0. compatibility we 
     # transform factors to character before grouping
-    # and back after grouping
+    # and back after grouping. The default behaviour has
+    # changed so we comment out the to character transformation
     
     factor_cols = names( select_if(data_spread, is.factor) )
     
     data_alluvial_id = data_spread %>%
       select( - !! id ) %>%
-      mutate_at( .vars = vars( one_of(factor_cols) ), as.character ) %>%
+      # mutate_at( .vars = vars( one_of(factor_cols) ), as.character ) %>%
       group_by_all() %>%
       count() %>%
       ungroup() %>%
@@ -240,12 +279,12 @@ alluvial_long = function( data
 
   # attach alluvial_id to id keys
   # will be attached to plot later
-  suppressMessages({
-
-    data_key = data_spread %>%
-      left_join( data_alluvial_id )
-
-  })
+  
+  join_by = names(data_spread)[names(data_spread) %in% names(data_alluvial_id)]
+  
+  data_key = data_spread %>%
+    left_join( data_alluvial_id, by =  join_by) %>%
+    mutate_if( is.factor, fct_drop)
 
   # compose fill columns
 
@@ -284,11 +323,12 @@ alluvial_long = function( data
       select( alluvial_id, value ) %>%
       rename( fill = value )
 
-    suppressMessages({
-      data_new = data_new %>%
-        left_join( data_fill )
-    })
+    join_by = names(data_new)[names(data_new) %in% names(data_fill)]
+    
+    data_new = data_new %>%
+      left_join( data_fill, by = join_by )
 
+          
   } else if( fill_by == 'all_flows'){
 
     data_new$fill = data_new$alluvial_id %>%
@@ -350,10 +390,8 @@ alluvial_long = function( data
   df_fill_flow = tibble( fill = unique(data_new$fill)
                          , fill_flow = col_vector_flow )
 
-  suppressMessages({
-    data_new = data_new %>%
-      left_join( df_fill_flow )
-  })
+  data_new = data_new %>%
+      left_join( df_fill_flow, by = 'fill' )
 
   # adjust col_vector length fill value
 
@@ -364,16 +402,15 @@ alluvial_long = function( data
   d_fill_value = tibble( value = unique(data_new$value)
                          , fill_value = col_vector_value )
 
-  suppressMessages({
-    data_new = data_new %>%
-      left_join( d_fill_value )
-  })
+  data_new = data_new %>%
+    left_join( d_fill_value, by = 'value' )
 
 
   if( ! is.null(fill_str) ){
 
     data_new = data_new %>%
       mutate( fill_value = ifelse( as.character(value) == as.character(!!fill)
+                                   & x == fill_str
                                    , fill_flow, fill_value ) )
   }
 
@@ -399,7 +436,8 @@ alluvial_long = function( data
     labs( x = '', y = 'count', caption = caption)
 
   if(stratum_labels){
-    p = p + geom_label( stat = ggalluvial::StatStratum )
+    p = p + geom_label( stat = ggalluvial::StatStratum
+                        , size = stratum_label_size )
   }
 
 
@@ -416,6 +454,8 @@ alluvial_long = function( data
   }
 
   p$data_key = data_key
+  p$alluvial_type = 'long'
+  p$alluvial_params = params
 
   return(p)
 }
