@@ -24,6 +24,33 @@ test_that('get_data_space'
 
 })
 
+
+test_that('pdp_parallel',{
+  
+  skip_if_not_installed("furrr")
+  
+  set.seed(0)
+  
+  df = select(mtcars2, -ids)
+  m = randomForest::randomForest( disp ~ ., df)
+  imp = m$importance
+  
+  pred_seq_old = get_pdp_predictions_seq(df, imp
+                                         , m
+                                         , degree = 3
+                                         , bins = 5)
+  
+  
+
+  pred_parallel =  pdp_predictions(df, imp
+                                   , m
+                                   , degree = 3
+                                   , bins = 5
+                                   , parallel = TRUE)
+  
+  expect_true(all(near(pred_seq_old, pred_parallel)))
+})
+
 test_that('pdp_methods'
   ,{
     
@@ -33,20 +60,54 @@ test_that('pdp_methods'
     m = randomForest::randomForest( disp ~ ., df)
     imp = m$importance
     
-    pred = get_pdp_predictions(df, imp
-                                #, .f_predict = predict
-                                , m
-                                , degree = 3
-                                , bins = 5)
+    pred_seq_old = get_pdp_predictions_seq(df, imp
+                                       , m
+                                       , degree = 3
+                                       , bins = 5)
     
+    
+    pred_seq = pdp_predictions(df, imp
+                               , m
+                               , degree = 3
+                               , bins = 5
+                               , parallel = FALSE)
+    
+
+    expect_true(all(near(pred_seq, pred_seq_old)))
+
     dspace = get_data_space(df, imp, degree = 3)
     
-    p = alluvial_model_response(pred, dspace, imp, degree = 3, method = 'pdp')
+    p = alluvial_model_response(pred_seq, dspace, imp, degree = 3, method = 'pdp')
     
-    vdiffr::expect_doppelganger('model_response_pdb', p)
+    expect_doppelganger('model_response_pdb', p)
     
 })
 
+test_that('pdp_methods_classification_non_binary'
+          ,{
+            
+    set.seed(0)
+    
+    df = select(mtcars2, -ids)
+    m = randomForest::randomForest(cyl ~ ., df)
+    imp = m$importance
+    
+    pred_seq = pdp_predictions(df, imp
+                               , m
+                               , degree = 3
+                               , bins = 5
+                               , parallel = FALSE)
+    
+
+    dspace = get_data_space(df, imp, degree = 3)
+    
+    p = alluvial_model_response(pred_seq, dspace, imp, degree = 3, method = 'pdp')
+    
+    expect_doppelganger('model_response_pdb_non_binary', p)
+    
+})
+
+
 test_that('alluvial_model_response'
           ,{
 
@@ -64,7 +125,7 @@ test_that('alluvial_model_response'
     
     p = alluvial_model_response(pred, dspace, imp, degree = 3)
     
-    vdiffr::expect_doppelganger('model_response', p)
+    expect_doppelganger('model_response', p)
     
     expect_equal( length( levels(p$data$x) ) - 1, 3 )
     
@@ -77,14 +138,10 @@ test_that('alluvial_model_response'
     # importance df contains unknown variable
 
     imp_no_match = bind_rows(imp_conv, tibble( vars = 'xxx', imp = 0.99) )
-    
+
     expect_error( get_data_space(df, imp_no_match) )
     expect_error( alluvial_model_response( pred, dspace, imp_no_match) )
   
-    # importance as less variables then degrees
-    expect_warning( get_data_space(df, imp_conv[0:2,], degree = 3) )
-    expect_warning( alluvial_model_response(pred, dspace, imp_conv[0:2,], degree = 3) )
-    
     # number of flows to high
     dspace = get_data_space(df, imp, degree = 6)
     pred = predict(m, newdata = dspace)
@@ -115,32 +172,33 @@ test_that('alluvial_model_response'
     
     p = alluvial_model_response(pred, dspace, imp, bin_labels = c('A','B','C','D','E'), degree = 3 )
     
-    vdiffr::expect_doppelganger('model_response_new_labs', p)
+    expect_doppelganger('model_response_new_labs', p)
     
     # change bin_numerics parameter for pred and bins
     
     p = alluvial_model_response(pred, dspace, imp, degree = 3
-                                , bins = 3
                                 , bin_labels = c('L','M', 'H')
-                                , params_bin_numeric_pred = list(center = F, scale = F, transform = F) )
+                                , params_bin_numeric_pred = list(bins = 3, center = F, scale = F, transform = F) )
     
 
-    expect_true( p$alluvial_params$bins == 3 )
+    expect_true( p$alluvial_params$params_bin_numeric_pred$bins == 3 )
     
-    vdiffr::expect_doppelganger('model_response_new_change_bins_3', p)
+    expect_doppelganger('model_response_new_change_bins_3', p)
     
     dspace = get_data_space(df, imp, degree = 4)
     pred = predict(m, newdata = dspace)
     p = alluvial_model_response(pred, dspace, imp, degree = 4
-                                , bins = 7, c('LLL','LL', 'ML', 'M', 'MH', 'HH', 'HHH') )
+                                , params_bin_numeric_pred = list(bins=7)
+                                , c('LLL','LL', 'ML', 'M', 'MH', 'HH', 'HHH') )
     
     pred_train = predict(m)
     
-    p = alluvial_model_response(pred, dspace, imp, degree = 4, bins = 7
-                            , bin_labels = c('LLL','LL', 'ML', 'M', 'MH', 'HH', 'HHH')
-                            , pred_train = pred_train )
+    p = alluvial_model_response(pred, dspace, imp, degree = 4
+                                , params_bin_numeric_pred = list(bins=7)
+                                , bin_labels = c('LLL','LL', 'ML', 'M', 'MH', 'HH', 'HHH')
+                                , pred_train = pred_train )
     
-    vdiffr::expect_doppelganger('model_response_new_change_bins_7', p)
+    expect_doppelganger('model_response_new_change_bins_7', p)
     
     # bivariate categorical response
     
@@ -153,7 +211,7 @@ test_that('alluvial_model_response'
     pred = predict(m, newdata = dspace,type = 'response')
     p = alluvial_model_response(pred, dspace, imp, degree = 3)
     
-    vdiffr::expect_doppelganger('model_response_cat_bi', p)
+    expect_doppelganger('model_response_cat_bi', p)
     
     # multivariate categorical response
     
@@ -166,7 +224,7 @@ test_that('alluvial_model_response'
     pred = predict(m, newdata = dspace,type = 'response')
     p = alluvial_model_response(pred, dspace, imp, degree = 3)
     
-    vdiffr::expect_doppelganger('model_response_cat_multi', p)
+    expect_doppelganger('model_response_cat_multi', p)
     
     # all factors -----------------------------------------------
     
@@ -185,7 +243,7 @@ test_that('alluvial_model_response'
     
     pred = predict(m, newdata = dspace,type = 'response')
     p = alluvial_model_response(pred, dspace, imp, degree = 3)
-    vdiffr::expect_doppelganger('model_response_all_facs', p)
+    expect_doppelganger('model_response_all_facs', p)
     
     # factors as character ---------------------------------------
     
@@ -214,47 +272,49 @@ test_that('alluvial_model_response'
     pred = predict(m, newdata = dspace)
     
     p = alluvial_model_response(pred, dspace, imp, degree = 3)
-    vdiffr::expect_doppelganger('model_response_all_nums', p)
+    expect_doppelganger('model_response_all_nums', p)
           })
 
 test_that('alluvial_model_response_caret'
           , {
+  skip_on_cran()
+  skip_if_not_installed("caret")
             
   df = select(mtcars2, -ids)
   
   set.seed(1)
   train = caret::train( disp ~ ., df, method = 'lm',trControl = caret::trainControl(method = 'none') )
-  p = alluvial_model_response_caret(train, degree = 3)
+  p = alluvial_model_response_caret(train, df, degree = 3)
   
-  # vdiffr::expect_doppelganger('model_response_caret_lm', p)
+  # expect_doppelganger('model_response_caret_lm', p)
   
-  p = alluvial_model_response_caret(train, degree = 3, method = 'pdp')
-  # vdiffr::expect_doppelganger('model_response_caret_lm_pdp', p)
+  p = alluvial_model_response_caret(train, df, degree = 3, method = 'pdp')
+  # expect_doppelganger('model_response_caret_lm_pdp', p)
   
   
   set.seed(0)
   train = caret::train( disp ~ ., df, method = 'rf',trControl = caret::trainControl(method = 'none'), importance = T )
-  p = alluvial_model_response_caret(train, degree = 3)
+  p = alluvial_model_response_caret(train, df, degree = 3)
   
-  # vdiffr::expect_doppelganger('model_response_caret_rf', p)
+  # expect_doppelganger('model_response_caret_rf', p)
   
   # change bin labels
-  p = alluvial_model_response_caret(train, degree = 3, bin_labels =  c('A','B','C','D','E') )
+  p = alluvial_model_response_caret(train, df, degree = 3, bin_labels =  c('A','B','C','D','E') )
   
-  # vdiffr::expect_doppelganger('model_response_caret_new_labs', p)
+  # expect_doppelganger('model_response_caret_new_labs', p)
   
   # categorical bivariate response 
   set.seed(1)
-  train = caret::train( am ~ ., df, method = 'rf',trControl = caret::trainControl(method = 'none'), importance = T )
-  p = alluvial_model_response_caret(train, degree = 3)
-  # vdiffr::expect_doppelganger('model_response_caret_cat_bi', p)
+  train = caret::train(am ~ ., df, method = 'rf',trControl = caret::trainControl(method = 'none'), importance = T )
+  p = alluvial_model_response_caret(train, df, degree = 3)
+  # expect_doppelganger('model_response_caret_cat_bi', p)
   
   
   # categorical multivariate response
   set.seed(1)
   train = caret::train( cyl ~ ., df, method = 'rf',trControl = caret::trainControl(method = 'none'), importance = T )
-  p = alluvial_model_response_caret(train, degree = 3)
-  # vdiffr::expect_doppelganger('model_response_caret_cat_multi', p)
+  p = alluvial_model_response_caret(train, df, degree = 3)
+  # expect_doppelganger('model_response_caret_cat_multi', p)
   
   # all facs
   set.seed(1)
@@ -263,8 +323,8 @@ test_that('alluvial_model_response_caret'
     select_if( is.factor )
   
   train = caret::train( Survived ~ ., df, method = 'rf',trControl = caret::trainControl(method = 'none'), importance = T )
-  p = alluvial_model_response_caret(train, degree = 3)
-  # vdiffr::expect_doppelganger('all_facs_caret', p)
+  p = alluvial_model_response_caret(train, df, degree = 3)
+  # expect_doppelganger('all_facs_caret', p)
   
   # all nums
   set.seed(1)
@@ -273,8 +333,8 @@ test_that('alluvial_model_response_caret'
     select_if( is.numeric )
   
   train = caret::train( disp ~ ., df, method = 'rf',trControl = caret::trainControl(method = 'none'), importance = T )
-  p = alluvial_model_response_caret(train, degree = 3)
-  # vdiffr::expect_doppelganger('all_nums_caret', p)
+  p = alluvial_model_response_caret(train, df, degree = 3)
+  # expect_doppelganger('all_nums_caret', p)
   
   # titanic example, + mix of factor and character features
   # regular random Forest will not allow this caret works around it
@@ -285,48 +345,110 @@ test_that('alluvial_model_response_caret'
     select(Survived, Sex, Embarked, title)
   
   m <- caret::train(Survived~.,data = df, method="rf",trControl=trc,importance=T)
-  p = alluvial_model_response_caret(train = m,degree = 3,bins=5,stratum_label_size = 2.8) 
+  p = alluvial_model_response_caret(train = m, df, degree = 3,bins=5,stratum_label_size = 2.8) 
   
   p_grid = add_marginal_histograms(p, data_input = df, plot = F) %>%
     add_imp_plot(p, df)
 
   })
 
-test_that('params_bin_numeric_pred',{
+test_that('alluvial_model_response_parsnip'
+          , {
+  skip_if_not_installed("parsnip")
+  skip_if_not_installed("vip")
+  skip_if_not_installed("workflows")
+  skip_on_cran()
+  
+  df = select(mtcars2, -ids)
   
-  # alluvial_model_response_caret
   set.seed(1)
-  df = select(mtcars2, -ids)
-  train = caret::train( disp ~ .
-                        , df, method = 'rf'
-                        , trControl = caret::trainControl(method = 'none')
-                        , importance = T)
   
-  p_trans = alluvial_model_response_caret(train, degree = 4)
+  m = parsnip::linear_reg(mode = "regression") %>%
+    parsnip::set_engine("lm")
   
-  p_no_trans = alluvial_model_response_caret(train, degree = 4
-                                             , params_bin_numeric_pred = list(transform = F, center = F, scale = F) )
+  rec_prep = recipes::recipe(disp ~ ., df) %>%
+    recipes::prep()
   
-  expect_true( ! all(levels(p_trans$data_key$pred) == levels(p_no_trans$data_key$pred)) )
+  m_form = parsnip::fit(m, disp ~ ., df)
   
-  # alluvial_model_response
+  wf <- workflows::workflow() %>%
+    workflows::add_model(m) %>%
+    workflows::add_recipe(rec_prep) %>%
+    parsnip::fit(df)
+  
+  m_wf <- workflows::pull_workflow_fit(wf)
+  
+  p = alluvial_model_response_parsnip(m_form, df, degree = 3)
+  p = alluvial_model_response_parsnip(m_wf, df, degree = 3)
+  p = alluvial_model_response_parsnip(wf, df, degree = 3)
+  
+  p = alluvial_model_response_parsnip(m_form, df, degree = 3, method = 'pdp')
+
   set.seed(0)
-  df = select(mtcars2, -ids)
-  m = randomForest::randomForest( disp ~ ., df)
-  imp = m$importance
-  dspace = get_data_space(df, imp, degree = 3)
   
-  pred = predict(m, newdata = dspace)
+  m_rf = parsnip::rand_forest(mode = "regression") %>%
+    parsnip::set_engine("randomForest") %>%
+    parsnip::fit(disp ~ ., df)
   
-  p_trans = alluvial_model_response(pred, dspace, imp, degree = 3)
+  p = alluvial_model_response_parsnip(m_rf, df, degree = 3)
   
-  p_no_trans = alluvial_model_response(pred, dspace, imp, degree = 3
-                                       , params_bin_numeric_pred = list(transform = F, center = F, scale = F))
+  # change bin labels
+  p = alluvial_model_response_parsnip(m_rf, df, degree = 3, bin_labels =  c('A','B','C','D','E') )
   
-  expect_true( ! all(levels(p_trans$data_key$pred) == levels(p_no_trans$data_key$pred)) )
+  # categorical bivariate response 
+  set.seed(1)
+  
+  m_rf = parsnip::rand_forest(mode = "classification") %>%
+    parsnip::set_engine("randomForest") %>%
+    parsnip::fit(am ~ ., df)
+  
+  p = alluvial_model_response_parsnip(m_rf, df, degree = 3)
+  p = alluvial_model_response_parsnip(m_rf, df, degree = 3, method = "pdp")
+  
+  # categorical multivariate response
+  set.seed(1)
+  
+  m_rf = parsnip::rand_forest(mode = "classification") %>%
+    parsnip::set_engine("randomForest") %>%
+    parsnip::fit(cyl ~ ., df)
+  
+  p = alluvial_model_response_parsnip(m_rf, df, degree = 3)
+  p = alluvial_model_response_parsnip(m_rf, df, degree = 3, method = "pdp")
+  
+  # all facs
+  set.seed(1)
+  
+  df = titanic %>%
+    select_if( is.factor )
+  
+  m_rf = parsnip::rand_forest(mode = "classification") %>%
+    parsnip::set_engine("randomForest") %>%
+    parsnip::fit(Survived ~ ., df)
+  
+  p = alluvial_model_response_parsnip(m_rf, df, degree = 3)
+  p = alluvial_model_response_parsnip(m_rf, df, degree = 3, method = "pdp")
+  
+  # all nums
+  set.seed(1)
+  
+  df = select(mtcars2, -ids) %>%
+    select_if( is.numeric )
+  
+  m_rf = parsnip::rand_forest(mode = "regression") %>%
+    parsnip::set_engine("randomForest") %>%
+    parsnip::fit(disp ~ ., df)
+  
+  p = alluvial_model_response_parsnip(m_rf, df, degree = 3)
+  p = alluvial_model_response_parsnip(m_rf, df, degree = 3, method = "pdp")
+  
+  p_grid = add_marginal_histograms(p, data_input = df, plot = F) %>%
+    add_imp_plot(p, df, plot = FALSE)
   
 })
 
+
+
+
 test_that('n_feats == degree',{
   
   set.seed(0)
@@ -337,13 +459,11 @@ test_that('n_feats == degree',{
   
   pred = predict(m, newdata = dspace)
   
-  expect_silent( pred <- get_pdp_predictions(df, imp, .f_predict = randomForest:::predict.randomForest
+  expect_message( pred <- get_pdp_predictions(df, imp, .f_predict = randomForest:::predict.randomForest
                                              , m = m, degree = 3) )
   
   p = alluvial_model_response(pred, dspace, imp, degree = 3)
   
   p_imp = plot_imp(p, df)
   
-  # vdiffr::expect_doppelganger('p_imp_nfeats_equal_degree', p_imp)
-
-})
\ No newline at end of file
+})
