@@ -11,11 +11,11 @@ test_that('plot_imp'
                       , trControl = caret::trainControl( method = 'none' )
                       , importance = TRUE )
   
-  p = alluvial_model_response_caret(train, degree = 3)
+  p = alluvial_model_response_caret(train, df, degree = 3)
   
-  p_imp = plot_imp(p, mtcars2)
+  p_imp = plot_imp(p, df)
   
-  vdiffr::expect_doppelganger('plot_imp', p_imp)
+  expect_doppelganger('plot_imp', p_imp)
   
 })
 
@@ -32,7 +32,9 @@ test_that('add_importance_plot'
   
   pred_train = caret::predict.train(train, df)
   
-  p = alluvial_model_response_caret(train, degree = 4, pred_train = pred_train)
+  # we can silence the warning by adjusting bins and labels but we want to 
+  # maintain more bins for pred_train
+  expect_warning(p <- alluvial_model_response_caret(train, df, degree = 4, pred_train = pred_train))
   
   p_grid = add_marginal_histograms(p, data_input = df, plot = F)
   
